==> haskell-ipynb-0.1-52-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ipynb
version: 0.1
id: ipynb-0.1-aW4k4Ium3kF6z0Vhv1MW2
key: ipynb-0.1-aW4k4Ium3kF6z0Vhv1MW2
license: BSD-3-Clause
copyright: Copyright (C) 2019 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
synopsis: Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.
category: Text
abi: 4324b8cf75c321a7c0ffd9d7742b3f20
exposed: True
exposed-modules:
    Data.Ipynb
import-dirs: /usr/lib/ghc-8.6.5/site-local/ipynb-0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/ipynb-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ipynb-0.1
hs-libraries: HSipynb-0.1-aW4k4Ium3kF6z0Vhv1MW2
depends:
    aeson-1.4.4.0-KIBRt7ojt2h8yml6gHrkIF base-4.12.0.0
    base64-bytestring-1.0.0.2-Isuu0DM5i6LOS2qIIf24 bytestring-0.10.8.2
    containers-0.6.0.1 text-1.2.3.1
    unordered-containers-0.2.10.0-DuDkJMfSb9t61flNcUovL1
haddock-interfaces: /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html: /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ipynb-0.1-55-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ipynb
version: 0.1
id: ipynb-0.1-Juau9bWrM3K3S6YTfvPLf9
key: ipynb-0.1-Juau9bWrM3K3S6YTfvPLf9
license: BSD-3-Clause
copyright: Copyright (C) 2019 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
synopsis: Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.
category: Text
abi: 55bf4a3a92c8939aa2c5da087d4348bb
exposed: True
exposed-modules:
    Data.Ipynb
import-dirs: /usr/lib/ghc-8.6.5/site-local/ipynb-0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/ipynb-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ipynb-0.1
hs-libraries: HSipynb-0.1-Juau9bWrM3K3S6YTfvPLf9
depends:
    aeson-1.4.4.0-HZF4dQ7ymfT471uy0aBwyJ base-4.12.0.0
    base64-bytestring-1.0.0.2-C0hiEzqCknwIpHHXqmcpJo
    bytestring-0.10.8.2 containers-0.6.0.1 text-1.2.3.1
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
haddock-interfaces: /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html: /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
